@@ -210,7 +210,19 @@ test = Arkivist("tests.json").reset()
 test.set("names", {})
 test.find("names").set("maria", 1)
 test.find("names").set("pedro", 1)
-print("Names:", test.string())
+print("Names:", test.find("names").get("juan", 0))
+
+## Example #19
+print("\nTest #20")
+test = Arkivist("tests.json").reset()
+test.appendIn("colors", "red")
+test.appendIn("colors", "blue")
+test.appendIn("colors", "green")
+test.appendIn("colors", ("orange", "purple"))
+test.set("numbers", {})
+test.find("numbers").appendIn("odd", (1, 3, 5, [7]))
+test.find("even").appendIn("numbers", 2)
+print("Lists:", test.show())
 
 
 
